/* *******************************************************************
   esp_mdns_ping_server
   A ESP8266 Network Scanner to scan your own network for devices

   List of mDNS Service types: http://www.dns-sd.org/ServiceTypes.html

   forum: https://forum.arduino.cc/t/esp8266-retrive-others-mac-adress-hostname/634286
          https://forum.arduino.cc/t/esp-netzwerk-scannen-resolve-mac-hostname-offene-ports/633180

   by noiasca
   2023-10-31 23.10 initial version
   
   ***************************************************************** */
   
#define VERSION "23.10"                // the version of this sketch
#include <ESP8266WiFi.h>               // comes with ESP core 
#include <ESP8266mDNS.h>               // comes with ESP core
#include <ESP8266HTTPClient.h>         // comes with ESP core
#include <ESP8266WebServer.h>          // comes with ESP core
#include <ESP8266Ping.h>               // V1.1.0 by Daniele Colanardi - manual download from https://github.com/dancol90/ESP8266Ping

//#include <credentials.h>               // if you have an external file with your credentials you can use it
#ifndef STASSID                        // either use an external .h file containing STASSID and STAPSK - or
//                                     // add defines to your boards - or
#define STASSID "your-ssid"            // ... modify these line to your SSID
#define STAPSK  "your-password"        // ... and set your WIFI password
#endif
const char ssid[] = STASSID;
const char password[] = STAPSK;

#include "client.h"                    // the webclient
#include "mdns.h"                      // MDNS and PING
#include "server.h"                    // the webserver to present the result

void setup() {
  Serial.begin(115200);
  delay(500);
  Serial.println("\r\nsetup()");
  char myhostname[32] = {0};
  sprintf(myhostname, "esp%06X", ESP.getChipId());  // generate a hostname
  Serial.print("Hostname: ");
  Serial.println(myhostname);
  WiFi.hostname(myhostname);

  WiFi.mode(WIFI_STA);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    Serial.print(".");
    delay(250);
  }
  Serial.println();
  Serial.print("Connected to ");
  Serial.println(ssid);
  Serial.print("IP address: ");
  Serial.println(WiFi.localIP());

  mdnsSetup(myhostname);
  serverSetup();
  Serial.printf("start loop");
}

void loop() {
  server.handleClient();               // call the webserver
  MDNS.update();                       // only on the ESP8266 (not on on ESP32)
  netscanTimer();                      // do all the network scanning
  if (Serial.read() == 'd') {          // just show some internal stored data
    debugData();
  }
}
//
